use std::path::PathBuf;

use thiserror::Error;

#[derive(Error, Debug)]
pub enum Error {
    #[error("Error in the player UI")]
    UiError(#[from] eframe::Error),
    #[error(transparent)]
    Other(#[from] anyhow::Error),
    #[error(
        r"The system does not seem to have the usual project dirs, like:
Linux:      /home/alice/.config/barapp
MS Windows: C:\Users\Alice\AppData\Roaming\Foo Corp\Bar App\config
Mac:        /Users/Alice/Library/Application Support/com.Foo-Corp.Bar-App

Closing as to not break your files accidentally."
    )]
    NoProjDir,
    #[error(r"The store file '{0}' where Beatbär stores it's metadata is not a regular file, refusing to save or load to keep your files safe.")]
    BadStoreFile(PathBuf),
    #[error(r"Could not convert the store to the binary format for saving it to the disk.")]
    RmpEncode(#[from] rmp_serde::encode::Error),
    #[error(r"Could not decode the store from the binary format for loading it from the disk. Is your store file broken?")]
    RmpDecode(#[from] rmp_serde::decode::Error),
    #[error(r"Error while reading or writing to the disk. Source: {0}")]
    IO(#[from] std::io::Error),
}
